from ctypes import *
from path import path
from headers import SCLFileHdr
from hobeta import HobetaFile

def load(scl):
    if getattr(scl, 'read', None):
        data = scl.read()
    elif getattr(scl, 'bytes', None):
        data = scl.bytes()
    else:
        scl = path(scl)
        data = scl.bytes()

    size = len(data)
    if size < 10:
        return None

    signature = 'SINCLAIR'
    if not data.startswith(signature):
        return None

    n_files = ord(data[len(signature)])
    if n_files == 0 or scl.size < len(signature) + 1 + n_files*sizeof(SCLFileHdr):
        return None

    files = []
    start = len(signature) + 1 + n_files*sizeof(SCLFileHdr)
    for i in range(n_files):
        hdr = SCLFileHdr()
        offset = len(signature) + 1 + i*sizeof(SCLFileHdr)
        memmove(addressof(hdr), data[offset:offset+sizeof(SCLFileHdr)], sizeof(SCLFileHdr))

        n_secs = hdr.n_secs if hdr.n_secs else 256
        length = 256 * n_secs
        files.append(HobetaFile(data[start:start+length], hdr))
        start += length

    # need to take into account checksum at the end of file
    if scl.size != start + 4:
        return None

    return files
